@@ -4,11 +4,15 @@
  *	cachedresult.cxx
  *
  *   DESCRIPTION
- *      implementation of the pqxx::CachedResult class.
- *   pqxx::CachedResult transparently fetches and caches query results on demand
+ *      implementation of the pqxx::cachedresult class.
+ *   pqxx::cachedresult transparently fetches and caches query results on demand
  *
  * Copyright (c) 2001-2003, Jeroen T. Vermeulen <jtv@xs4all.nl>
  *
+ * See COPYING for copyright license.  If you did not receive a file called
+ * COPYING with this source code, please notify the distributor of this mistake,
+ * or contact the author.
+ *
  *-------------------------------------------------------------------------
  */
 #include <stdexcept>
@@ -19,24 +23,16 @@ using namespace PGSTD;
 
 
 
-pqxx::CachedResult::CachedResult(pqxx::Transaction_base &Trans,
-                                 const char Query[],
-				 const PGSTD::string &BaseName,
-				 size_type Granularity) :
-  m_Granularity(Granularity),
-  m_Cache(),
-  m_Cursor(Trans, Query, BaseName, Granularity),
-  m_EmptyResult(),
-  m_HaveEmpty(false)
+void pqxx::cachedresult::init()
 {
   // We can't accept granularity of 1 here, because some block number 
   // arithmetic might overflow.
   if (m_Granularity <= 1)
-    throw out_of_range("Invalid CachedResult granularity");
+    throw out_of_range("Invalid cachedresult granularity");
 }
 
 
-pqxx::CachedResult::size_type pqxx::CachedResult::size() const
+pqxx::cachedresult::size_type pqxx::cachedresult::size() const
 {
   if (m_Cursor.size() == Cursor::pos_unknown)
   {
@@ -47,7 +43,7 @@ pqxx::CachedResult::size_type pqxx::CachedResult::size() const
 }
 
 
-bool pqxx::CachedResult::empty() const
+bool pqxx::cachedresult::empty() const
 {
   return (m_Cursor.size() == 0) ||
          ((m_Cursor.size() == Cursor::pos_unknown) &&
@@ -56,7 +52,7 @@ bool pqxx::CachedResult::empty() const
 }
 
 
-void pqxx::CachedResult::MoveTo(blocknum Block) const
+void pqxx::cachedresult::MoveTo(blocknum Block) const
 {
   if (Block < 0)
     throw out_of_range("Negative result set index");
@@ -68,15 +64,15 @@ void pqxx::CachedResult::MoveTo(blocknum Block) const
 }
 
 
-const pqxx::Result &pqxx::CachedResult::Fetch() const
+const pqxx::result &pqxx::cachedresult::Fetch() const
 {
   size_type Pos = m_Cursor.Pos();
 
-  const Result R( m_Cursor.Fetch(m_Granularity) );
+  const result R( m_Cursor.Fetch(m_Granularity) );
 
   if (!R.empty()) 
   {
-    pair<const long, const Result> tmp_pair(BlockFor(Pos), R);
+    pair<const long, const result> tmp_pair(BlockFor(Pos), R);
     m_Cache.insert(tmp_pair);
     // TODO: Use iterator returned by insert().  
     return m_Cache[BlockFor(Pos)];
