@@ -18,8 +18,8 @@
 #include <new>
 #include <stdexcept>
 
-#include "pqxx/except.h"
-#include "pqxx/result.h"
+#include "pqxx/except"
+#include "pqxx/result"
 
 
 using namespace PGSTD;
@@ -167,13 +167,13 @@ pqxx::result::GetLength(pqxx::result::size_type Row,
 
 pqxx::result::field pqxx::result::tuple::operator[](const char f[]) const
 {
-  return field(*this, m_Home->ColumnNumber(f));
+  return field(*this, m_Home->column_number(f));
 }
 
 
 pqxx::result::field pqxx::result::tuple::at(const char f[]) const
 {
-  const int fnum = m_Home->ColumnNumber(f);
+  const int fnum = m_Home->column_number(f);
   if (fnum == -1)
     throw invalid_argument(string("Unknown field '") + f + "'");
 
@@ -181,7 +181,8 @@ pqxx::result::field pqxx::result::tuple::at(const char f[]) const
 }
 
 
-pqxx::result::field pqxx::result::tuple::at(pqxx::result::tuple::size_type i) const
+pqxx::result::field 
+pqxx::result::tuple::at(pqxx::result::tuple::size_type i) const
 {
   if ((i < 0) || (i >= size()))
     throw out_of_range("Invalid field number");
@@ -190,6 +191,27 @@ pqxx::result::field pqxx::result::tuple::at(pqxx::result::tuple::size_type i) co
 }
 
 
+const char *
+pqxx::result::column_name(pqxx::result::tuple::size_type Number) const
+{
+  const char *const N = PQfname(m_Result, Number);
+  if (!N) 
+    throw out_of_range("Invalid column number: " + ToString(Number));
+
+  return N;
+}
+
+
+pqxx::result::tuple::size_type
+pqxx::result::column_number(const char ColName[]) const
+{
+  const tuple::size_type N = PQfnumber(m_Result, ColName);
+  if (N == -1)
+    throw invalid_argument("Unknown column name: '" + string(ColName) + "'");
+
+  return N;
+}
+
 
 // const_iterator
 
