@@ -15,8 +15,8 @@
  *
  *-------------------------------------------------------------------------
  */
-#include "pqxx/tablereader.h"
-#include "pqxx/transaction.h"
+#include "pqxx/tablereader"
+#include "pqxx/transaction"
 
 using namespace PGSTD;
 
@@ -40,12 +40,12 @@ pqxx::tablereader::~tablereader()
   }
   catch (const exception &e)
   {
-    Trans().ProcessNotice(e.what());
+    Trans().process_notice(e.what());
   }
 }
 
 
-bool pqxx::tablereader::GetRawLine(string &Line)
+bool pqxx::tablereader::get_raw_line(string &Line)
 {
   m_Done = !Trans().ReadCopyLine(Line);
   return !m_Done;
