@@ -1,10 +1,10 @@
 #include <iostream>
 #include <vector>
 
-#include <pqxx/connection.h>
-#include <pqxx/tablewriter.h>
-#include <pqxx/transaction.h>
-#include <pqxx/result.h>
+#include <pqxx/connection>
+#include <pqxx/tablewriter>
+#include <pqxx/transaction>
+#include <pqxx/result>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -22,7 +22,7 @@ using namespace pqxx;
 // backend running on host foo.bar.net, logging in as user smith.
 //
 // The tablename argument determines which table the data will be written to.
-// If none is given, it defaults to "orgevents".
+// If none is given, it defaults to "pqxxorgevents".
 int main(int argc, char *argv[])
 {
   try
@@ -30,16 +30,16 @@ int main(int argc, char *argv[])
     // Set up a connection to the backend
     connection C(argv[1]);
 
-    string TableName((argc > 2) ? argv[2] : "orgevents");
+    string TableName((argc > 2) ? argv[2] : "pqxxorgevents");
 
     // First create a separate transaction to drop old table, if any.  This may
     // fail if the table didn't previously exist.
     cout << "Dropping old " << TableName << endl;
     try
     {
-      Transaction Drop(C, "drop_" + TableName);
-      Drop.Exec(("DROP TABLE " + TableName).c_str());
-      Drop.Commit();
+      transaction<> Drop(C, "drop_" + TableName);
+      Drop.exec(("DROP TABLE " + TableName).c_str());
+      Drop.commit();
     }
     catch (const sql_error &e)
     {
@@ -48,9 +48,9 @@ int main(int argc, char *argv[])
     }
 
     // Now begin new transaction to create new table & write data
-    Transaction T(C, "test5");
+    transaction<> T(C, "test5");
 
-    T.Exec(("CREATE TABLE " + 
+    T.exec(("CREATE TABLE " + 
 	    TableName + 
 	    "(year INTEGER, event VARCHAR)").c_str());
 
@@ -99,7 +99,7 @@ int main(int argc, char *argv[])
     }
 
     // Now that our tablewriter is closed, it's safe to commit T.
-    T.Commit();
+    T.commit();
   }
   catch (const sql_error &e)
   {
