@@ -1,9 +1,9 @@
 #include <cstdio>
 #include <iostream>
 
-#include <pqxx/connection.h>
-#include <pqxx/transaction.h>
-#include <pqxx/result.h>
+#include <pqxx/connection>
+#include <pqxx/transaction>
+#include <pqxx/result>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -27,19 +27,19 @@ int main(int argc, char *argv[])
     const string Table = ((argc >= 3) ? argv[2] : "pg_tables");
 
     connection C(argv[1]);
-    Transaction T(C, "test11");
+    transaction<> T(C, "test11");
 
-    result R( T.Exec("SELECT * FROM " + Table) );
+    result R( T.exec("SELECT * FROM " + Table) );
 
     // Print column names
     for (result::tuple::size_type c = 0; c < R.Columns(); ++c)
     {
-      string N= R.ColumnName(c);
+      string N= R.column_name(c);
       cout << c << ":\t" << N << endl;
-      if (R.ColumnNumber(N) != c)
+      if (R.column_number(N) != c)
 	throw logic_error("Expected column '" + N + 
 			  "' to be no. " + ToString(c) + ", "
-			  "but it was no. " + ToString(R.ColumnNumber(N)));
+			  "but it was no. " + ToString(R.column_number(N)));
     }
 
     // If there are rows in R, compare their metadata to R's.
@@ -55,7 +55,7 @@ int main(int argc, char *argv[])
 
       for (result::tuple::size_type c = 0; c < R[0].size(); ++c)
       {
-	string N = R.ColumnName(c);
+	string N = R.column_name(c);
 
 	if (string(R[0].at(c).c_str()) != R[0].at(N).c_str())
           throw logic_error("Field " + ToString(c) + " contains "
@@ -66,10 +66,10 @@ int main(int argc, char *argv[])
           throw logic_error("Field " + ToString(c) + " ('" + N + "'): "
 			    "at() inconsistent with operator[]!");
 
-	if (R[0][c].Name() != N)
+	if (R[0][c].name() != N)
 	  throw logic_error("Field " + ToString(c) + " "
 			    "called '" + N + "' by result, "
-			    "but '" + R[0][c].Name() + "' by Field object");
+			    "but '" + R[0][c].name() + "' by Field object");
 
 	if (size_t(R[0][c].size()) != strlen(R[0][c].c_str()))
 	  throw logic_error("Field '" + N + "' "
