@@ -2,9 +2,9 @@
 #include <iostream>
 #include <vector>
 
-#include <pqxx/connection.h>
-#include <pqxx/transaction.h>
-#include <pqxx/result.h>
+#include <pqxx/connection>
+#include <pqxx/transaction>
+#include <pqxx/result>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -42,18 +42,18 @@ int main(int argc, char *argv[])
     connection C(argv[1]);
 
     // Tell C we won't be needing it for a while (not true, but let's pretend)
-    C.Deactivate();
+    C.deactivate();
 
     // Now set up some data structures
     vector<int> NullFields;		// Maps column to no. of null fields
     vector<bool> SortedUp, SortedDown;	// Does column appear to be sorted?
 
     // ...And reactivate C (not really needed, but it sounds more polite)
-    C.Activate();
+    C.activate();
 
-    Transaction T(C, "test12");
+    transaction<> T(C, "test12");
 
-    result R( T.Exec("SELECT * FROM " + Table) );
+    result R( T.exec("SELECT * FROM " + Table) );
 
     InitVector(NullFields, R.Columns(), 0);
     InitVector(SortedUp, R.Columns(), true);
@@ -147,7 +147,7 @@ int main(int argc, char *argv[])
     for (result::tuple::size_type f = 0; f < R.Columns(); ++f)
     {
       cout << ToString(f) << ":\t"
-	   << R.ColumnName(f) << '\t'
+	   << R.column_name(f) << '\t'
 	   << NullFields[f] << '\t'
 	   << (SortedUp[f] ? 
 		(SortedDown[f] ? "equal" : "up" ) : 
