@@ -2,12 +2,12 @@
 #include <iostream>
 #include <stdexcept>
 
-#include <pqxx/connection.h>
-#include <pqxx/nontransaction.h>
-#include <pqxx/result.h>
-#include <pqxx/robusttransaction.h>
-#include <pqxx/transaction.h>
-#include <pqxx/transactor.h>
+#include <pqxx/connection>
+#include <pqxx/nontransaction>
+#include <pqxx/result>
+#include <pqxx/robusttransaction>
+#include <pqxx/transaction>
+#include <pqxx/transactor>
 
 using namespace PGSTD;
 using namespace pqxx;
@@ -22,13 +22,13 @@ using namespace pqxx;
 // called template1, or "host=foo.bar.net user=smith" to connect to a
 // backend running on host foo.bar.net, logging in as user smith.
 //
-// The program will attempt to add an entry to a table called "events",
+// The program will attempt to add an entry to a table called "pqxxevents",
 // with a key column called "year"--and then abort the change.
 
 namespace
 {
 
-// Let's take a boring year that is not going to be in the "events" table
+// Let's take a boring year that is not going to be in the "pqxxevents" table
 const int BoringYear = 1977;
 
 
@@ -51,10 +51,10 @@ public:
     const string CountQuery = "SELECT count(*) FROM " + m_Table;
     result R;
 
-    R = T.Exec(CountQuery);
+    R = T.exec(CountQuery);
     R.at(0).at(0).to(m_Results.first);
 
-    R = T.Exec(CountQuery + " WHERE year=" + ToString(BoringYear));
+    R = T.exec(CountQuery + " WHERE year=" + ToString(BoringYear));
     R.at(0).at(0).to(m_Results.second);
   }
 };
@@ -74,7 +74,7 @@ public:
 
   void operator()(argument_type &T)
   {
-    T.Exec("INSERT INTO " + m_Table + " VALUES (" +
+    T.exec("INSERT INTO " + m_Table + " VALUES (" +
 	   ToString(BoringYear) + ", " + Quote("yawn") + ")");
 
     throw runtime_error("Transaction deliberately aborted");
@@ -112,10 +112,10 @@ int main(int argc, char *argv[])
   {
     connection C(argv[1]);
 
-    const string Table = ((argc > 2) ? argv[2] : "events");
+    const string Table = ((argc > 2) ? argv[2] : "pqxxevents");
 
     pair<int,int> Before;
-    C.Perform(CountEvents(Table, Before));
+    C.perform(CountEvents(Table, Before));
     if (Before.second) 
       throw runtime_error("Table already has an event for " + 
 		          ToString(BoringYear) + ", "
@@ -125,7 +125,7 @@ int main(int argc, char *argv[])
 
     try
     {
-      C.Perform(DoomedTransaction);
+      C.perform(DoomedTransaction);
     }
     catch (const exception &e)
     {
@@ -133,7 +133,7 @@ int main(int argc, char *argv[])
     }
 
     pair<int,int> After;
-    C.Perform(CountEvents(Table, After));
+    C.perform(CountEvents(Table, After));
 
     if (After != Before)
       throw logic_error("Event counts changed from "
